PALM-meteo: palmmeteo_stdplugins/synthetic.py File Reference

PALM-meteo

Classes | Namespaces | Functions | Variables
synthetic.py File Reference

## Classes
class | palmmeteo_stdplugins.synthetic.SyntheticPlugin
class | palmmeteo_stdplugins.synthetic.ProfileInterpolator

## Namespaces
namespace | palmmeteo_stdplugins
namespace | palmmeteo_stdplugins.synthetic

## Functions
def | palmmeteo_stdplugins.synthetic.expand (var)
def | palmmeteo_stdplugins.synthetic.stretch_heights (heights, terrain_ratio, gp0, t0, p_surf, p_trans)

## Variables
| palmmeteo_stdplugins.synthetic.barom_pres = PalmPhysics.barom_lapse0_pres
| palmmeteo_stdplugins.synthetic.barom_gp = PalmPhysics.barom_lapse0_gp
| palmmeteo_stdplugins.synthetic.g = PalmPhysics.g